@@ -1,7 +1,7 @@
 """Top-level package for Python ClimaCell API."""
 
-from .pyclimacell import ClimaCell, ClimaCellSync
+from .pyclimacell import ClimaCellV3, ClimaCellV4, ClimaCellV3Sync, ClimaCellV4Sync
 
 __author__ = """raman325"""
 __email__ = "7243222+raman325@users.noreply.github.com"
-__version__ = "0.14.0"
+__version__ = "0.15.0"
